=======================
MoMapper (Mongo Mapper)
=======================

Python Mapper for MongoDB models


.. image:: https://img.shields.io/pypi/v/momapper.svg
    :target: https://pypi.python.org/pypi/momapper

.. image:: https://img.shields.io/travis/OvalMoney/momapper.svg
    :target: https://travis-ci.org/OvalMoney/momapper

Features
--------

* Schema validation for documents.
* Type validation for document fields.
* 100% compatible with Pymongo API.
* Implements Mapper_ design pattern, separating schema and type validation from storage logic.

Installation:
-------------

.. code-block:: console

    $ pip install momapper

Usage:
------

Check it out in the doc_.

License
-------

Free software: MIT_ license.

Credits
-------

This package was created with Cookiecutter_ and the `wboxx1/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`wboxx1/cookiecutter-pypackage`: https://github.com/wboxx1/cookiecutter-pypackage-poetry
.. _MIT: ./LICENSE
.. _Mapper: https://en.wikipedia.org/wiki/Data_mapper_pattern
.. _doc: ./docs/usage.rst
